@@ -166,78 +166,8 @@ ANOVA_design <- function(design, n, mu, sd, r = 0,
   
   #Code by Lisa De Bruine. Allows multiple inputs for r - only use single value now.
   #from: https://github.com/debruine/faux/blob/master/R/rnorm_multi.R
-  generate_cor_matrix  <- function(vars = 3, cors = 0, mu = 0, sd = 1) {
-    if (length(mu) == 1) {
-      mu <- rep(mu, vars)
-    } else if (length(mu) != vars) {
-      stop("the length of mu must be 1 or vars");
-    }
-    
-    if (length(sd) == 1) {
-      sd <- rep(sd, vars)
-    } else if (length(sd) != vars) {
-      stop("the length of sd must be 1 or vars");
-    }
-    
-    # correlation matrix
-    if (class(cors) == "numeric" & length(cors) == 1) {
-      if (cors >=-1 & cors <=1) {
-        cors = rep(cors, vars*(vars-1)/2)
-      } else {
-        stop("cors must be between -1 and 1")
-      }
-    }
-    
-    if (class(cors) == "matrix") {
-      if (!is.numeric(cors)) {
-        stop("cors matrix not numeric")
-      } else if (dim(cors)[1] != vars || dim(cors)[2] != vars) {
-        stop("cors matrix wrong dimensions")
-      } else if (sum(cors == t(cors)) != (nrow(cors)^2)) {
-        stop("cors matrix not symmetric")
-      } else {
-        cor_mat <- cors
-      }
-    } else if (length(cors) == vars*vars) {
-      cor_mat <- matrix(cors, vars)
-    } else if (length(cors) == vars*(vars-1)/2) {
-      # generate full matrix from vector of upper right triangle
-      
-      cor_mat <- matrix(nrow=vars, ncol = vars)
-      upcounter = 1
-      lowcounter = 1
-      for (col in 1:vars) {
-        for (row in 1:vars) {
-          if (row == col) {
-            # diagonal
-            cor_mat[row, col] = 1
-          } else if (row > col) {
-            # lower left triangle
-            cor_mat[row, col] = cors[lowcounter]
-            lowcounter <- lowcounter + 1
-          }
-        }
-      }
-      for (row in 1:vars) {
-        for (col in 1:vars) {
-          if (row < col) {
-            # upper right triangle
-            cor_mat[row, col] = cors[upcounter]
-            upcounter <- upcounter + 1
-          }
-        }
-      }
-    }
-    
-    # check matrix is positive definite
-    tol <- 1e-08
-    ev <- eigen(cor_mat, only.values = TRUE)$values
-    if (sum(ev < tol)) {
-      stop("correlation matrix not positive definite")
-    }
-    
-    return(cor_mat)
-  }
+  #Now stored in non-exported function
+  
   cor_mat <- generate_cor_matrix(vars = vars, cors = cors)
   
   sd_for_sigma <- sd #added to prevent changing sd which is now passed on
@@ -407,7 +337,7 @@ ANOVA_design <- function(design, n, mu, sd, r = 0,
       geom_point(position = position_dodge(width = 0.9), shape = 10, size = 5, stat = "identity") + #Personal preference for sd -- ARC
       geom_errorbar(aes(ymin = mu - sd, ymax = mu + sd),
                     position = position_dodge(width = 0.9), size = .6, width = .3) +
-      coord_cartesian(ylim = c(min(mu) - sd, max(mu) + sd)) +
+      #coord_cartesian(ylim = c(min(mu) - max(sd), max(mu) + max(sd))) +
       theme_bw(base_size = 16) + ggtitle("Means for each condition in the design") 
     
   } else {
@@ -416,7 +346,7 @@ ANOVA_design <- function(design, n, mu, sd, r = 0,
       geom_point(position = position_dodge(width = 0.9), shape = 10, size = 5, stat = "identity") + #Personal preference for sd -- ARC
       geom_errorbar(aes(ymin = mu - sd, ymax = mu + sd),
                     position = position_dodge(width = 0.9), size = .6, width = .3) +
-      coord_cartesian(ylim = c(min(mu) - sd, max(mu) + sd)) +
+      #coord_cartesian(ylim = c(min(mu) - sd, max(mu) + sd)) +
       theme_bw() + ggtitle("Means for each condition in the design") 
   }
   if (plot == TRUE) {
@@ -424,7 +354,8 @@ ANOVA_design <- function(design, n, mu, sd, r = 0,
   }
   
   # Return results in list()
-  invisible(list(dataframe = dataframe,
+  ## Now S3 method
+  structure(list(dataframe = dataframe,
                  design = design,
                  design_list = design_list,
                  factors = factors,
@@ -440,5 +371,6 @@ ANOVA_design <- function(design, n, mu, sd, r = 0,
                  labelnames = labelnames,
                  labelnameslist = labelnameslist,
                  factornames = factornames,
-                 meansplot = meansplot2))
+                 meansplot = meansplot2),
+            class = "design_aov")
 }
